# 基于信息论的复杂系统分析

## 研究动机

在复杂系统分析中，如果采用传统手段如磁流体力学和偏微分方程等来进行建模，
往往需要诸多假设，而且数值计算和模拟十分困难；如果采用现在流行的机器学习算法如
神经网络来进行建模，虽然有时候会效果不错，但是模型往往缺乏可解释性，且非常容易过拟合。
两种手段是皆有利弊，并不能完全解决我们的问题，而信息论是一种与模型无关的分析工具，
既可以与传统手段相结合使得模型建模得到简化；又可以与流行机器学习算法结合提高模型可解释性。

到目前为止，我们已经有很多工具可以刻画随机变量之间的关系，例如互相关系数可以用来刻画两个随机变量之间的线性关系，
互信息可以用来刻画非线性关系。而实际应用时，我们所观测到其实都是关于某些变量的时间序列数据，现在的目标就是如果
从得到的时间序列数据当中挖掘出隐藏在其中的依赖关系。

假设我们要研究的是一个耦合的物理系统：通过对系统变量$\mathcal{X},\mathcal{Y},\mathcal{Z},\ldots$在时间$t\in 1\ldots T$的观测，而产生观测时间序列数据：
$$
  \{x_1,\ldots,x_T\},\ \ \{y_1,\ldots,y_T\},\ \ \{z_1,\ldots,z_T\}, \ldots,
$$
这些时间序列可以看做随机过程
$$\mathbf{X}=\{X_t\}_{t=0}^{\infty},\ \ \mathbf{Y}=\{Y_t\}_{t=0}^{\infty},\ \ \mathbf{Z}=\{Y_t\}_{t=0}^{\infty},\ldots$$
中随机变量$X_t,Y_t,Z_t,\ldots$的实例化$x_t,y_t,z_t,\ldots$，其中随机过程可以理解成一列以时间$t$为下角标的随机变量组成的集合。

通过观察记录复杂系统中各个变量的时间序列数据：
$$
    \{x_t,y_t,z_t,\ldots\}_{t=0}^{\infty},
$$
我们的最终目标是解决如下问题:

- **如何根据所观测到的时间序列$\mathbf{\{x_t, y_{t}, z_{t}, \ldots\}_{t=0}^{\infty}}$，构建整个系统变量的因果依赖图，并可视化系统变量之间的信息流动，以及对系统衍化做出合理的推测？**

直接考虑上述比较复杂且难以实现，可以逐步进行分析和考虑，例如：

- 首先，通过观测数据序列$\{x_t\}_{t=0}^{\infty}, \{y_t\}_{t=0}^{\infty}, \{z_t\}_{t=0}^{\infty}, ... $来推断系统变量$X,Y,Z,...$之间的关联关系，
并且分析其依赖关系是否为本质的，以及是否存在时间延迟，并确定具体时间延迟。
- 然后，假设我们有一个要预测的目标变量$Y$，挖掘系统中其他变量$X_1,X_2,X_3,...$对预测目标变量$Y$的重要性，从中筛选出对$Y$有关键贡献的变量集合$v_Y$，
并进行排序，而且需要考虑它们之间的协同作用和时间延迟。
- 以前两步的分析为基础，考虑整个系统的所有变量，基于观测到的时间序列数据重构它们之间的因果网络图，
结合概率图、GNN&动态图衍化以及物理模型，对系统衍化做出合理推测，为研究整个系统的动力学衍化提供参考。


## 方法路径

初步按照如下三个步骤：

- 第一步：基于转移熵的关联分析
- 第二步：基于条件转移熵的参数挖掘
- 第三步：因果网络图构建

## 因果网络图构建

目前主要有两种算法：贪婪算法和PCMCIA算法


### 贪婪算法

贪婪算法的思想比较简单：首先初始化集合$V_X$为空集，然后递归地往集合$V_X$里添加影响因素，每一次都从剩下变量里选择最重要地变量，
可以使用条件转移熵来筛选，递归结束后，可以再使用统计检验的方法做一遍检查，剔除不重要的，类似于决策树的剪枝过程。

### PCMCI

PCMCI分为两个部分：MCI表示momentary conditional indepence，也就是条件独立性测试，具体就是使用上面介绍的转移熵和条件转移熵；PC是两个
数学家的名字首字母缩写，代表一种图论的筛选算法。

两种算法具体不再这里展开了，基本思想都是一种迭代更新。